/*
 * Copyright (c) 2007, to-do. All rights reserved.
 */
static char* op2str[] = {
"",
"void",
"addA",
"subA",
"mulA",
"divA",
"modA",
"powA",
"bitandA",
"bitorA",
"bitsubA",
"bitxorA",
"bitshLA",
"bitshRA",
"andA",
"orA",
"inc",
"dec",
"echo",
"doc",
"crlf",
"if",
"else",
"for",
"while",
"do",
"foreach",
"switch",
"default",
"try",
"break",
"continue",
"in",
"not",
"string",
"sharp",
"case",
"mod",
"bitand",
"char",
"paL",
"paR",
"mul",
"add",
"comma",
"sub",
"join",
"div",
"catch",
"throw",
"return",
"exit",
"goto",
"Minclude",
"Mdefine",
"var",
"label",
"function",
"colon",
"semic",
"lt",
"store",
"gt",
"que",
"class",
"file",
"line",
"names",
"stdin",
"stdout",
"stderr",
"tmpout",
"tmperr",
"frameIn",
"frameOut",
"jump",
"load",
"copy",
"sand",
"pop",
"call",
"args",
"array",
"object",
"loop",
"plus",
"minus",
"bitnot",
"toBool",
"toChar",
"toInt",
"sqL",
"toFloat",
"sqR",
"bitxor",
"toString",
"regex",
"toNumber",
"typeof",
"delete",
"new",
"null",
"true",
"false",
"this",
"symbol",
"int",
"float",
"match",
"notmatch",
"and",
"or",
"eq",
"ne",
"cmp",
"bitshL",
"bitshR",
"pow",
"???",
"???",
"???",
"???",
"???",
"cuL",
"bitor",
"cuR",
"bitsub",
NULL
};

